pub fn parse_journalctl_error(stderr: &str) -> LogDiagnosticExpand description
Parse journalctl stderr to determine the specific error type
pub fn parse_journalctl_error(stderr: &str) -> LogDiagnosticParse journalctl stderr to determine the specific error type