Module systemd

Module systemd 

Structs

ManagerProxy
Proxy object for org.freedesktop.systemd1.Manager. Partially taken from https://github.com/lucab/zbus_systemd/blob/main/src/systemd1/generated.rs
ServiceProxy
Proxy object for org.freedesktop.systemd1.Service. Taken from https://github.com/lucab/zbus_systemd/blob/main/src/systemd1/generated.rs
UnitId
Just enough info to fully identify a unit
UnitProxy
Proxy object for org.freedesktop.systemd1.Unit. Taken from https://github.com/lucab/zbus_systemd/blob/main/src/systemd1/generated.rs
UnitWithStatus

Enums

Scope
UnitScope

Functions

get_active_state
Returns the load state of a systemd unit
get_all_services
get_main_pid
Returns the PID of a systemd service
get_unit_file_location
get_unit_file_state
Returns the unit file state of a systemd unit. If the state is enabled, the unit loads on every boot
get_unit_path
Unit file path for a service
reload
restart_service
sleep_test
start_service
stop_service